@@ -13,6 +13,7 @@
 #include <opencv2/gapi/own/exports.hpp> // GAPI_EXPORTS
 #include <opencv2/gapi/gkernel.hpp>     // GKernelType[M], GBackend
 #include <opencv2/gapi/infer.hpp>       // Generic
+#include <opencv2/gapi/infer/workload_type.hpp>
 
 #include <map>
 
@@ -66,6 +67,8 @@ struct ParamDesc {
         LayerVariantAttr<std::vector<float>> scale_values;
 
         LayerVariantAttr<int> interpolation;
+
+        bool clamp_outputs = false;
     };
 
     struct CompiledModel {
@@ -99,6 +102,8 @@ struct ParamDesc {
     PluginConfigT config;
 
     size_t nireq = 1;
+
+    bool ensure_named_tensors = false;
 };
 
 // NB: Just helper to avoid code duplication.
@@ -205,6 +210,24 @@ public:
         return *this;
     }
 
+    /** @brief Ensures the model has named tensors.
+
+    This function is used to ensure that all tensors in the model have names.
+    It goes through all input and output nodes of the model and sets the names
+    if they are not set. This is neccessary for models with nameless tensors.
+
+    If a tensor does not have a name, it will be assigned a default name
+    based on the producer node's friendly name. If the producer node has multiple
+    outputs, the name will be in the form "node_name:N", where N is the output index.
+
+    @param flag If true, then it guarantees that all tensors will have names.
+    @return reference to this parameter structure.
+     */
+    Params<Net>& cfgEnsureNamedTensors(bool flag = true) {
+        m_desc.ensure_named_tensors = flag;
+        return *this;
+    }
+
     /** @brief Specifies tensor layout for an input layer.
 
     The function is used to set tensor layout for an input layer.
@@ -336,6 +359,24 @@ public:
         return *this;
     }
 
+    /** @brief Enables or disables clamping of model outputs in the PrePostProcessor.
+
+    By default, output values are clamped to the valid range for the output precision
+    by the device or plugin. Enabling this option moves clamping to the PrePostProcessor stage.
+
+    @note This feature is only available with OpenVINO 2025.2 and newer.
+
+    @param flag If true, clamping is performed in the PrePostProcessor;
+    otherwise, it is handled by the device or plugin.
+    @return reference to this parameter structure.
+    */
+    Params<Net>&
+    cfgClampOutputs(bool flag = true) {
+        detail::getModelToSetAttrOrThrow(m_desc.kind, "clamp outputs")
+            .clamp_outputs = std::move(flag);
+        return *this;
+    }
+
     /** @brief Specifies the new shape for input layers.
 
     The function is used to set new shape for input layers.
@@ -524,6 +565,12 @@ public:
         return *this;
     }
 
+    /** @see ov::Params::cfgEnsureNamedTensors. */
+    Params& cfgEnsureNamedTensors(bool flag = true) {
+        m_desc.ensure_named_tensors = flag;
+        return *this;
+    }
+
     /** @see ov::Params::cfgInputTensorLayout. */
     Params& cfgInputTensorLayout(std::string layout) {
         detail::getModelToSetAttrOrThrow(m_desc.kind, "input tensor layout")
@@ -599,6 +646,14 @@ public:
         return *this;
     }
 
+    /** @see ov::Params::cfgClampOutputs. */
+    Params&
+    cfgClampOutputs(bool flag = true) {
+        detail::getModelToSetAttrOrThrow(m_desc.kind, "clamp outputs")
+            .clamp_outputs = std::move(flag);
+        return *this;
+    }
+
     /** @see ov::Params::cfgReshape. */
     Params& cfgReshape(std::vector<size_t> new_shape) {
         detail::getModelToSetAttrOrThrow(m_desc.kind, "reshape")
@@ -691,6 +746,9 @@ namespace wip { namespace ov {
  */
 struct benchmark_mode { };
 
+class WorkloadTypeOV : public WorkloadType {};
+using WorkloadTypeOVPtr = std::shared_ptr<cv::gapi::wip::ov::WorkloadTypeOV>;
+
 } // namespace ov
 } // namespace wip
 
@@ -702,6 +760,10 @@ namespace detail
     {
         static const char* tag() { return "gapi.wip.ov.benchmark_mode"; }
     };
+    template<> struct CompileArgTag<cv::gapi::wip::ov::WorkloadTypeOVPtr>
+    {
+        static const char* tag() { return "gapi.wip.ov.workload_type"; }
+    };
 }
 
 } // namespace cv
